@@ -1,15 +1,10 @@
 import os
-import sysconfig
 from subprocess import Popen, PIPE
 from textops import find
 
-DEV=False
-
 def get_reference_dir(packname):
-    if DEV:
-        return packname
-    else:
-        base_dir = sysconfig.get_path("purelib")
+        base_dir = os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
+        #base_dir = sysconfig.get_path("purelib")
         return os.path.join(base_dir, packname)
 
 def get_resources_dir(packname="manafa", default_res_dir="resources"):
